import win32serviceutil
import win32service
import win32event
import servicemanager
import logging
from healthcheck.healthservice import HealthService

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger('healthcheck.%s' % __name__)

# mostly taken from http://code.activestate.com/recipes/576451-how-to-create-a-windows-service-in-python/
# and http://tebl.homelinux.com/view_document.php?view=6
class SupermSvc(win32serviceutil.ServiceFramework):

    _svc_name_ = 'HealthCheckSvc'
    _svc_display_name_ = 'HealthCheckSvc'
    _svc_description_ = 'HealthCheck is your friendly neighborhood daemon with a dirty job to do.'

    def __init__(self, args):
        self.service = HealthService(dict())
        self.service.interval = 10
        self.service.timeout = 60
        self.service.dry_run = False
        self.service.configure_logger()
        win32serviceutil.ServiceFramework.__init__(self, args)
        self.hWaitStop = win32event.CreateEvent(None, 0, 0, None)
        self.isAlive = True

    def SvcStop(self):
        self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
        self.isAlive = False

    def SvcDoRun(self):
        while self.isAlive:
            logger.info('Beginning execution of scripts in directory {0} at interval {1} minutes'.format(self.service.scriptdir, self.service.interval))
            win32event.WaitForSingleObject(self.hWaitStop, int(self.service.interval) * 6000)
            self.service.execute()
        win32event.SetEvent(self.hWaitStop)
        
    def main(self):
        pass

        
if __name__ == '__main__':   
   win32serviceutil.HandleCommandLine(SupermSvc)
