#!/bin/bash

PLATFORM_OPENSSL_DIR=$(openssl version -d 2> /dev/null | sed -re 's/OPENSSLDIR: "([^"]+)"/\1/')

set -e

CURRENT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
cd "${CURRENT_DIR}"

# these cert locations were inspired from the go-language crypto/x509 package
# https://go.dev/src/crypto/x509/root_linux.go
POSSIBLE_CERTS_FILES=( "/etc/ssl/certs/ca-certificates.crt" "/etc/pki/tls/certs/ca-bundle.crt" "/etc/ssl/ca-bundle.pem" "/etc/pki/tls/cacert.pem" "/etc/pki/ca-trust/extracted/pem/tls-ca-bundle.pem" "/etc/ssl/cert.pem" )
POSSIBLE_CERTS_DIRS=( "/etc/ssl/certs" "/etc/pki/tls/certs" "/etc/openssl/certs" "/usr/local/share/certs" "/var/ssl/certs" )

if [[ "${PLATFORM_OPENSSL_DIR}" != "" ]]; then
  POSSIBLE_CERTS_FILES=("${PLATFORM_OPENSSL_DIR}/cert.pem" "${POSSIBLE_CERTS_FILES[@]}")
  POSSIBLE_CERTS_DIRS=("${PLATFORM_OPENSSL_DIR}/certs" "${POSSIBLE_CERTS_DIRS[@]}")
fi

SOURCE_CERTS_FILE=""
for f in "${POSSIBLE_CERTS_FILES[@]}"
do
  if [[ -f "${f}" ]]; then
    SOURCE_CERTS_FILE=$(readlink -e "${f}")
    break
  fi
done

SOURCE_CERTS_DIR=""
for d in "${POSSIBLE_CERTS_DIRS[@]}"
do
  if [[ "$(ls -A ${d} 2>/dev/null)" ]]; then
    SOURCE_CERTS_DIR=$(readlink -e "${d}")
    break
  fi
done

CERTS_SETUP=FALSE

if [[ -f "${SOURCE_CERTS_FILE}" ]]; then
  TARGET_CERTS_FILE="cert.pem"
  echo "Using '${SOURCE_CERTS_FILE}' as ssl cert file."
  rm -f "${TARGET_CERTS_FILE}"
  ln -s "${SOURCE_CERTS_FILE}" "${TARGET_CERTS_FILE}"
  CERTS_SETUP=TRUE
fi

if [[ -d "${SOURCE_CERTS_DIR}" ]]; then
  TARGET_CERTS_DIR="certs"
  echo "Using '${SOURCE_CERTS_DIR}' as ssl certs dir."
  rm -fd "${TARGET_CERTS_DIR}"
  ln -s "${SOURCE_CERTS_DIR}" "${TARGET_CERTS_DIR}"
  CERTS_SETUP=TRUE
fi

if [[ "${CERTS_SETUP}" != "TRUE" ]]; then
  echo "Unable to find ssl certs. Please install platform's ca certificates package."
  exit 1
fi
